@@ -19,6 +19,7 @@ from six import StringIO
 from burlap import Satchel
 from burlap.constants import *
 from burlap.decorators import task
+from burlap.postgresql import POSTGRESQL, POSTGIS
 from burlap.trackers import BaseTracker
 
 
@@ -424,7 +425,7 @@ class DjangoSatchel(Satchel):
                 pass
 
     @task
-    def manage(self, cmd, site=None, *args, **kwargs):
+    def manage(self, cmd, *args, site=None, **kwargs):
         """
         A generic wrapper around Django's manage command.
 
@@ -700,7 +701,7 @@ class DjangoSatchel(Satchel):
     @task
     def migrate(
         self, app='', migration='', site=None, fake=0, ignore_errors=None, database=None, migrate_apps='',
-        delete_ghosts=1
+        delete_ghosts=1, drop_connections=1
     ):
         # pylint: disable=anomalous-backslash-in-string
         """
@@ -715,6 +716,7 @@ class DjangoSatchel(Satchel):
             database: Database on which to migrate apps
             migrate_apps: Apps to migrate (defaults to all)
             delete_ghosts: Delete ghost migrations (South-only)
+            drop_connections: Drop all db connections before migration, to prevent locks (Postgres-only)
 
         To pass a comma-delimited list in a fab command, escape the comma with a backslash.
 
@@ -727,14 +729,11 @@ class DjangoSatchel(Satchel):
         r = self.local_renderer
 
         ignore_errors = int(r.env.ignore_migration_errors if ignore_errors is None else ignore_errors)
-
-        delete_ghosts = int(delete_ghosts)
+        delete_ghosts = int(delete_ghosts and self.version_tuple < (1, 9, 0))
+        drop_connections = int(drop_connections)
 
         post_south = self.version_tuple >= (1, 7, 0)
 
-        if self.version_tuple >= (1, 9, 0):
-            delete_ghosts = 0
-
         migrate_apps = migrate_apps or ''
         migrate_apps = [
             _.strip().split('.')[-1]
@@ -781,11 +780,13 @@ class DjangoSatchel(Satchel):
                 self.vprint('project_dir1:', r.env.project_dir, r.genv.get('dj_project_dir'), r.genv.get('project_dir'))
                 r.env.SITE = _site
                 with self.settings(warn_only=ignore_errors):
+                    if drop_connections and r.env.db_engine.split('.')[-1] in {POSTGRESQL, POSTGIS}:
+                        # Drop database connections that may lock or interfere with migrations.
+                        self.get_satchel('postgresql').drop_connections()
                     r.run_or_local(
                         'export SITE={SITE}; export ROLE={ROLE}; {migrate_pre_command} cd {project_dir}; '
                         '{manage_cmd} migrate --noinput {migrate_merge} --traceback '
-                        '{migrate_database} {delete_ghosts} {migrate_app} {migrate_migration} '
-                        '{migrate_fake_str}')
+                        '{migrate_database} {delete_ghosts} {migrate_app} {migrate_migration} {migrate_fake_str}')
 
     @task
     def truncate(self, app):
